@@ -307,3 +307,40 @@ fn spawn_test_error_exit_code() {
     let output = child.wait_with_output().unwrap();
     assert!(!output.status.success());
 }
+
+#[test]
+#[should_panic]
+fn run_or_exit_error_code() {
+    let args = vec![];
+    let options = ScriptOptions::new();
+
+    run_or_exit("exit 1", &args, &options);
+}
+
+#[test]
+#[should_panic]
+fn run_or_exit_invocation_error() {
+    let args = vec![];
+    let options = ScriptOptions::new();
+
+    run_or_exit("badcommand", &args, &options);
+}
+
+#[test]
+fn run_or_exit_pipe_output() {
+    let args = vec![];
+    let mut options = ScriptOptions::new();
+    options.output_redirection = IoOptions::Pipe;
+
+    let (output, error) = run_or_exit(
+        r#"
+        echo "Test"
+        exit 0
+        "#,
+        &args,
+        &options,
+    );
+
+    assert!(!output.is_empty());
+    assert!(error.is_empty());
+}
